from pylablib.devices import Thorlabs

class Stage():
    min_step = 46694 / 10

    def __init__(self):
        self.motor_x = Thorlabs.KinesisMotor("80855672")
        self.motor_y = Thorlabs.KinesisMotor("80855670")
        self.motor_z = Thorlabs.KinesisMotor("80855667")

    def stop_all(self):
        self.motor_x.stop()
        self.motor_y.stop()
        self.motor_z.stop()

    #################################################################
    # MOVE MOTORS BY A NUMBER OF STEPS
    #################################################################

    def move_x(self, nb_steps):
        if self.motor_x.is_moving() == False:
            self.motor_x.move_by(nb_steps*self.min_step) 
            self.motor_x.wait_move()

    def move_y(self, nb_steps):
        if self.motor_y.is_moving() == False:
            self.motor_y.move_by(-nb_steps*self.min_step) 
            self.motor_y.wait_move()

    def move_z(self, nb_steps):
        if self.motor_z.is_moving() == False:
            self.motor_z.move_by(nb_steps*self.min_step) 
            self.motor_z.wait_move()

    #################################################################
    # MOVE MOTORS TO A GIVEN POSITION
    #################################################################

    def move_x_to(self, position):
        self.motor_x.move_to(position)
        self.motor_x.wait_for_move_complete()

    def move_y_to(self, position):
        self.motor_y.move_to(position)
        self.motor_y.wait_for_move_complete()

    def move_z_to(self, position):
        self.motor_z.move_to(position)
        self.motor_z.wait_for_move_complete()

    #################################################################
    # GET THE POSITION
    #################################################################

    def get_x_pos(self):
        return self.motor_x.get_position() / 46694.
    
    def get_y_pos(self):
        return self.motor_y.get_position() / 46694.
    
    def get_z_pos(self):
        return self.motor_z.get_position() / 46694.